server

package
v0.0.0-...-c61727f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 18, 2026 License: Apache-2.0 Imports: 23 Imported by: 0

Documentation

Overview

Package server provides the local bundle development server.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BundleServer

type BundleServer struct {
	BaseDir          string
	Bundle           *bundle.Bundle
	DockerCli        *dockerclient.Client
	MassdriverClient *mdclient.Client
	// contains filtered or unexported fields
}

BundleServer is the local development server for building and testing bundles.

func New

func New(dir string) (*BundleServer, error)

New creates a BundleServer for the bundle at dir.

func (*BundleServer) RegisterHandlers

func (b *BundleServer) RegisterHandlers(ctx context.Context)

RegisterHandlers registers with the DefaultServeMux to handle requests

func (*BundleServer) Start

func (b *BundleServer) Start(port string, launchBrowser bool) error

Start begins listening on the given port and optionally opens the UI in a browser.

func (*BundleServer) Stop

func (b *BundleServer) Stop(ctx context.Context) error

Stop gracefully shuts down the HTTP server.

Directories

Path Synopsis
Package bundle provides HTTP handlers for the local bundle development server.
Package bundle provides HTTP handlers for the local bundle development server.
Package version provides an HTTP handler for reporting the current CLI version.
Package version provides an HTTP handler for reporting the current CLI version.

Jump to